==> bibledit-0.7.tar.gz: bibledit-0.7/src/dialogcompanion.cpp <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/


#include "libraries.h"
#include "dialogcompanion.h"
#include "utilities.h"


CompanionDialog::CompanionDialog (Configuration * configuration)
{
  companiondialog = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (companiondialog), "Bibledit Windows Companions");
  gtk_window_set_position (GTK_WINDOW (companiondialog), GTK_WIN_POS_CENTER_ON_PARENT);
  gtk_window_set_modal (GTK_WINDOW (companiondialog), TRUE);

  dialog_vbox1 = GTK_DIALOG (companiondialog)->vbox;
  gtk_widget_show (dialog_vbox1);

  vbox1 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox1);
  gtk_box_pack_start (GTK_BOX (dialog_vbox1), vbox1, TRUE, TRUE, 0);

  label1 = gtk_label_new ("Bibledit can work together with a \"Bibledit Windows Companion\".\nThis companion gives Bibledit access to some Bible translation\nprograms that run on Wine.");
  gtk_widget_show (label1);
  gtk_box_pack_start (GTK_BOX (vbox1), label1, FALSE, FALSE, 10);
  gtk_misc_set_alignment (GTK_MISC (label1), 0, 0.5);

  checkbutton1 = gtk_check_button_new_with_mnemonic ("Use the companion");
  gtk_widget_show (checkbutton1);
  gtk_box_pack_start (GTK_BOX (vbox1), checkbutton1, FALSE, FALSE, 0);
  // Set the checkbutton.
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton1), configuration->companion_enabled);

  dialog_action_area1 = GTK_DIALOG (companiondialog)->action_area;
  gtk_widget_show (dialog_action_area1);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area1), GTK_BUTTONBOX_END);

  cancelbutton = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (cancelbutton);
  gtk_dialog_add_action_widget (GTK_DIALOG (companiondialog), cancelbutton, GTK_RESPONSE_CANCEL);
  GTK_WIDGET_SET_FLAGS (cancelbutton, GTK_CAN_DEFAULT);

  okbutton = gtk_button_new_from_stock ("gtk-ok");
  gtk_widget_show (okbutton);
  gtk_dialog_add_action_widget (GTK_DIALOG (companiondialog), okbutton, GTK_RESPONSE_OK);
  GTK_WIDGET_SET_FLAGS (okbutton, GTK_CAN_DEFAULT);

  g_signal_connect ((gpointer) okbutton, "clicked", G_CALLBACK (companiondialog_on_okbutton_clicked), gpointer (this));

  gtk_widget_grab_focus (checkbutton1);
  gtk_widget_grab_default (okbutton);
}


CompanionDialog::~CompanionDialog ()
{
  gtk_widget_destroy (companiondialog);
}


int
CompanionDialog::run ()
{
  return gtk_dialog_run (GTK_DIALOG (companiondialog));
}


void
CompanionDialog::on_okbutton_clicked ()
{
  local = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbutton1));
}


void
CompanionDialog::companiondialog_on_okbutton_clicked (GtkButton * button, gpointer user_data)
{
  ((CompanionDialog *) user_data)->on_okbutton_clicked ();
}

==> bibledit-0.9.tar.gz: bibledit-0.9/src/dialogcompanion.cpp <==
/*
** Copyright (C) 2003-2005 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/


#include "libraries.h"
#include "dialogcompanion.h"
#include "utilities.h"


CompanionDialog::CompanionDialog (Configuration * configuration)
{
  companiondialog = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (companiondialog), "Bibledit Windows Companion");
  gtk_window_set_position (GTK_WINDOW (companiondialog), GTK_WIN_POS_CENTER_ON_PARENT);
  gtk_window_set_modal (GTK_WINDOW (companiondialog), TRUE);

  dialog_vbox1 = GTK_DIALOG (companiondialog)->vbox;
  gtk_widget_show (dialog_vbox1);

  vbox1 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox1);
  gtk_box_pack_start (GTK_BOX (dialog_vbox1), vbox1, TRUE, TRUE, 0);

  label1 = gtk_label_new ("Bibledit can work together with a \"Bibledit Windows Companion\".\nThis companion gives Bibledit access to some Bible translation\nprograms that run on Wine.");
  gtk_widget_show (label1);
  gtk_box_pack_start (GTK_BOX (vbox1), label1, FALSE, FALSE, 10);
  gtk_misc_set_alignment (GTK_MISC (label1), 0, 0.5);

  checkbutton1 = gtk_check_button_new_with_mnemonic ("Use the companion");
  gtk_widget_show (checkbutton1);
  gtk_box_pack_start (GTK_BOX (vbox1), checkbutton1, FALSE, FALSE, 0);
  // Set the checkbutton.
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton1), configuration->companion_enabled);

  dialog_action_area1 = GTK_DIALOG (companiondialog)->action_area;
  gtk_widget_show (dialog_action_area1);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area1), GTK_BUTTONBOX_END);

  cancelbutton = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (cancelbutton);
  gtk_dialog_add_action_widget (GTK_DIALOG (companiondialog), cancelbutton, GTK_RESPONSE_CANCEL);
  GTK_WIDGET_SET_FLAGS (cancelbutton, GTK_CAN_DEFAULT);

  okbutton = gtk_button_new_from_stock ("gtk-ok");
  gtk_widget_show (okbutton);
  gtk_dialog_add_action_widget (GTK_DIALOG (companiondialog), okbutton, GTK_RESPONSE_OK);
  GTK_WIDGET_SET_FLAGS (okbutton, GTK_CAN_DEFAULT);

  g_signal_connect ((gpointer) okbutton, "clicked", G_CALLBACK (companiondialog_on_okbutton_clicked), gpointer (this));

  gtk_widget_grab_focus (checkbutton1);
  gtk_widget_grab_default (okbutton);
}


CompanionDialog::~CompanionDialog ()
{
  gtk_widget_destroy (companiondialog);
}


int
CompanionDialog::run ()
{
  return gtk_dialog_run (GTK_DIALOG (companiondialog));
}


void
CompanionDialog::on_okbutton_clicked ()
{
  local = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbutton1));
}


void
CompanionDialog::companiondialog_on_okbutton_clicked (GtkButton * button, gpointer user_data)
{
  ((CompanionDialog *) user_data)->on_okbutton_clicked ();
}
